@@ -341,9 +341,9 @@ Creates a new session on an Elluminate server, using the C<createSession> comman
 	password => 'secret',
 	start =>  $session_start,
 	end => $session_end,
+        restricted => 1,
 	privateMeeting => 1,
 	recordingStatus => 'remote',
-	raiseHandOnEnter => 1,
 	maxTalkers => 2,
 	boundaryMinutes => 15,
 	fullPermissions => 1,
@@ -911,7 +911,7 @@ for today (starting in 5 minutes), tomorrow and the following day:
 	facilitatorId     => Elive->login->userId,
 	password          => 'sssh!',
 	privateMeeting    => 1,
-	restrictedMeeting => 1,
+	restricted        => 1,
         participants => '*the_team',
 	start =>  $start_msec,
 	end   => $end_msec,
